# Templateco
An ecosystem for generating customisable templated folders.

## Getting Started
```shell
$ pip install templateco templateco-cli templateco-name-plugin
# Successfully installed!

$ templateco make template folder
```

1. This will install Templateco, the CLI and the terraform module.
2. Create a Terraform folder called foo.
